@@ -29,6 +29,8 @@
 
 #define FALLBACK_NAME "??"
 
+#define NETK_APPLICATION_GET_PRIVATE(o)    (G_TYPE_INSTANCE_GET_PRIVATE ((o), NETK_TYPE_APPLICATION, NetkApplicationPrivate))
+
 static GHashTable *app_hash = NULL;
 
 struct _NetkApplicationPrivate
@@ -72,43 +74,33 @@ static void netk_application_class_init (NetkApplicationClass * klass);
 static void netk_application_finalize (GObject * object);
 
 
-static gpointer parent_class;
+static GObjectClass *parent_class;
 static guint signals[LAST_SIGNAL] = { 0 };
 
 GType
 netk_application_get_type (void)
 {
-    static GType object_type = 0;
+    static GType type = G_TYPE_INVALID;
 
-    g_type_init ();
-
-    if (!object_type)
+    if (G_UNLIKELY (type == G_TYPE_INVALID))
     {
-        static const GTypeInfo object_info = {
-            sizeof (NetkApplicationClass),
-            (GBaseInitFunc) NULL,
-            (GBaseFinalizeFunc) NULL,
-            (GClassInitFunc) netk_application_class_init,
-            NULL,               /* class_finalize */
-            NULL,               /* class_data */
-            sizeof (NetkApplication),
-            0,                  /* n_preallocs */
-            (GInstanceInitFunc) netk_application_init,
-        };
-
-        object_type =
-            g_type_register_static (G_TYPE_OBJECT, "NetkApplication",
-                                    &object_info, 0);
+        type = _netk_g_type_register_simple (G_TYPE_OBJECT,
+                                             "NetkApplication",
+                                             sizeof (NetkApplicationClass),
+                                             netk_application_class_init,
+                                             sizeof (NetkApplication),
+                                             netk_application_init,
+                                             0);                                    
     }
 
-    return object_type;
+    return type;
 }
 
 static void
 netk_application_init (NetkApplication * application)
 {
-    application->priv = g_new0 (NetkApplicationPrivate, 1);
-
+    application->priv = NETK_APPLICATION_GET_PRIVATE (application);
+    
     application->priv->icon_cache = p_netk_icon_cache_new ();
     p_netk_icon_cache_set_want_fallback (application->priv->icon_cache, FALSE);
 }
@@ -117,20 +109,22 @@ static void
 netk_application_class_init (NetkApplicationClass * klass)
 {
     GObjectClass *object_class = G_OBJECT_CLASS (klass);
+    
+    g_type_class_add_private (klass, sizeof (NetkApplicationPrivate));
 
     parent_class = g_type_class_peek_parent (klass);
 
     object_class->finalize = netk_application_finalize;
 
     signals[NAME_CHANGED] =
-        g_signal_new ("name_changed", G_OBJECT_CLASS_TYPE (object_class),
+        g_signal_new (I_("name_changed"), G_OBJECT_CLASS_TYPE (object_class),
                       G_SIGNAL_RUN_LAST,
                       G_STRUCT_OFFSET (NetkApplicationClass, name_changed),
                       NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE,
                       0);
 
     signals[ICON_CHANGED] =
-        g_signal_new ("icon_changed", G_OBJECT_CLASS_TYPE (object_class),
+        g_signal_new (I_("icon_changed"), G_OBJECT_CLASS_TYPE (object_class),
                       G_SIGNAL_RUN_LAST,
                       G_STRUCT_OFFSET (NetkApplicationClass, icon_changed),
                       NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE,
@@ -154,8 +148,6 @@ netk_application_finalize (GObject * object)
 
     g_free (application->priv->name);
 
-    g_free (application->priv);
-
     G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
